@@ -2,9 +2,9 @@ from __future__ import annotations
 
 from typing import List
 
-from langchain_core.tools import BaseToolkit
+from langchain_core.tools import BaseTool
+from langchain_core.tools.base import BaseToolkit
 
-from langchain_community.tools import BaseTool
 from langchain_community.tools.json.tool import (
     JsonGetValueTool,
     JsonListKeysTool,
