@@ -30,7 +30,7 @@ class NLATool(Tool):
             The API endpoint tool.
         """
         expanded_name = (
-            f'{api_title.replace(" ", "_")}.{chain.api_operation.operation_id}'
+            f"{api_title.replace(' ', '_')}.{chain.api_operation.operation_id}"
         )
         description = (
             f"I'm an AI from {api_title}. Instruct what you want,"
@@ -62,7 +62,7 @@ class NLATool(Tool):
             verbose: Whether to print verbose output. Default is False.
             return_intermediate_steps: Whether to return intermediate steps.
                 Default is False.
-            **kwargs: Additional arguments.
+            kwargs: Additional arguments.
 
         Returns:
             The tool.
