@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, List
 
-from langchain_core.pydantic_v1 import Field
-from langchain_core.tools import BaseToolkit
+from langchain_core.tools import BaseTool
+from langchain_core.tools.base import BaseToolkit
+from pydantic import ConfigDict, Field
 
-from langchain_community.tools import BaseTool
 from langchain_community.tools.office365.create_draft_message import (
     O365CreateDraftMessage,
 )
@@ -40,10 +40,9 @@ class O365Toolkit(BaseToolkit):
 
     account: Account = Field(default_factory=authenticate)
 
-    class Config:
-        """Pydantic config."""
-
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(
+        arbitrary_types_allowed=True,
+    )
 
     def get_tools(self) -> List[BaseTool]:
         """Get the tools in the toolkit."""
