@@ -2,27 +2,83 @@
 
 from typing import List
 
+from langchain_core.caches import BaseCache as BaseCache
+from langchain_core.callbacks import Callbacks as Callbacks
 from langchain_core.language_models import BaseLanguageModel
-from langchain_core.pydantic_v1 import Field
-from langchain_core.tools import BaseToolkit
+from langchain_core.tools import BaseTool
+from langchain_core.tools.base import BaseToolkit
+from pydantic import ConfigDict, Field
 
-from langchain_community.tools import BaseTool
 from langchain_community.tools.sql_database.tool import (
     InfoSQLDatabaseTool,
     ListSQLDatabaseTool,
     QuerySQLCheckerTool,
-    QuerySQLDataBaseTool,
+    QuerySQLDatabaseTool,
+)
+from langchain_community.tools.sql_database.tool import (
+    QuerySQLDataBaseTool as QuerySQLDataBaseTool,  # keep import for backwards compat.
 )
 from langchain_community.utilities.sql_database import SQLDatabase
 
 
 class SQLDatabaseToolkit(BaseToolkit):
-    """Toolkit for interacting with SQL databases.
+    """SQLDatabaseToolkit for interacting with SQL databases.
 
-    Parameters:
-        db: SQLDatabase. The SQL database.
-        llm: BaseLanguageModel. The language model.
-    """
+    Setup:
+        Install ``langchain-community``.
+
+        .. code-block:: bash
+
+            pip install -U langchain-community
+
+    Key init args:
+        db: SQLDatabase
+            The SQL database.
+        llm: BaseLanguageModel
+            The language model (for use with QuerySQLCheckerTool)
+
+    Instantiate:
+        .. code-block:: python
+
+            from langchain_community.agent_toolkits.sql.toolkit import SQLDatabaseToolkit
+            from langchain_community.utilities.sql_database import SQLDatabase
+            from langchain_openai import ChatOpenAI
+
+            db = SQLDatabase.from_uri("sqlite:///Chinook.db")
+            llm = ChatOpenAI(temperature=0)
+
+            toolkit = SQLDatabaseToolkit(db=db, llm=llm)
+
+    Tools:
+        .. code-block:: python
+
+            toolkit.get_tools()
+
+    Use within an agent:
+        .. code-block:: python
+
+            from langchain import hub
+            from langgraph.prebuilt import create_react_agent
+
+            # Pull prompt (or define your own)
+            prompt_template = hub.pull("langchain-ai/sql-agent-system-prompt")
+            system_message = prompt_template.format(dialect="SQLite", top_k=5)
+
+            # Create agent
+            agent_executor = create_react_agent(
+                llm, toolkit.get_tools(), state_modifier=system_message
+            )
+
+            # Query agent
+            example_query = "Which country's customers spent the most?"
+
+            events = agent_executor.stream(
+                {"messages": [("user", example_query)]},
+                stream_mode="values",
+            )
+            for event in events:
+                event["messages"][-1].pretty_print()
+    """  # noqa: E501
 
     db: SQLDatabase = Field(exclude=True)
     llm: BaseLanguageModel = Field(exclude=True)
@@ -32,10 +88,9 @@ class SQLDatabaseToolkit(BaseToolkit):
         """Return string representation of SQL dialect to use."""
         return self.db.dialect
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(
+        arbitrary_types_allowed=True,
+    )
 
     def get_tools(self) -> List[BaseTool]:
         """Get the tools in the toolkit."""
@@ -58,7 +113,7 @@ class SQLDatabaseToolkit(BaseToolkit):
             f"'xxxx' in 'field list', use {info_sql_database_tool.name} "
             "to query the correct table fields."
         )
-        query_sql_database_tool = QuerySQLDataBaseTool(
+        query_sql_database_tool = QuerySQLDatabaseTool(
             db=self.db, description=query_sql_database_tool_description
         )
         query_sql_checker_tool_description = (
@@ -79,3 +134,6 @@ class SQLDatabaseToolkit(BaseToolkit):
     def get_context(self) -> dict:
         """Return db context that you may want in agent prompt."""
         return self.db.get_context()
+
+
+SQLDatabaseToolkit.model_rebuild()
