@@ -8,11 +8,12 @@ from typing import Any, Dict, List, Optional
 
 from langchain.chains.base import Chain
 from langchain.chains.llm import LLMChain
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks.manager import CallbackManagerForChainRun
 from langchain_core.language_models import BaseLanguageModel
 from langchain_core.prompts.base import BasePromptTemplate
 from langchain_core.prompts.prompt import PromptTemplate
-from langchain_core.pydantic_v1 import Field
+from pydantic import Field
 
 from langchain_community.chains.graph_qa.prompts import SPARQL_QA_PROMPT
 from langchain_community.graphs import NeptuneRdfGraph
@@ -75,6 +76,11 @@ def extract_sparql(query: str) -> str:
     return query
 
 
+@deprecated(
+    since="0.3.15",
+    removal="1.0",
+    alternative_import="langchain_aws.create_neptune_sparql_qa_chain",
+)
 class NeptuneSparqlQAChain(Chain):
     """Chain for question-answering against a Neptune graph
     by generating SPARQL statements.
@@ -113,6 +119,37 @@ class NeptuneSparqlQAChain(Chain):
     extra_instructions: Optional[str] = None
     """Extra instructions by the appended to the query generation prompt."""
 
+    allow_dangerous_requests: bool = False
+    """Forced user opt-in to acknowledge that the chain can make dangerous requests.
+
+    *Security note*: Make sure that the database connection uses credentials
+        that are narrowly-scoped to only include necessary permissions.
+        Failure to do so may result in data corruption or loss, since the calling
+        code may attempt commands that would result in deletion, mutation
+        of data if appropriately prompted or reading sensitive data if such
+        data is present in the database.
+        The best way to guard against such negative outcomes is to (as appropriate)
+        limit the permissions granted to the credentials used with this tool.
+
+        See https://python.langchain.com/docs/security for more information.
+    """
+
+    def __init__(self, **kwargs: Any) -> None:
+        """Initialize the chain."""
+        super().__init__(**kwargs)
+        if self.allow_dangerous_requests is not True:
+            raise ValueError(
+                "In order to use this chain, you must acknowledge that it can make "
+                "dangerous requests by setting `allow_dangerous_requests` to `True`."
+                "You must narrowly scope the permissions of the database connection "
+                "to only include necessary permissions. Failure to do so may result "
+                "in data corruption or loss or reading sensitive data if such data is "
+                "present in the database."
+                "Only use this chain if you understand the risks and have taken the "
+                "necessary precautions. "
+                "See https://python.langchain.com/docs/security for more information."
+            )
+
     @property
     def input_keys(self) -> List[str]:
         return [self.input_key]
@@ -144,7 +181,7 @@ class NeptuneSparqlQAChain(Chain):
             )
         sparql_generation_chain = LLMChain(llm=llm, prompt=sparql_prompt)
 
-        return cls(  # type: ignore[call-arg]
+        return cls(
             qa_chain=qa_chain,
             sparql_generation_chain=sparql_generation_chain,
             examples=examples,
