@@ -7,7 +7,7 @@ from typing import Any, Dict, List, Optional
 from langchain.chains import LLMChain
 from langchain.chains.base import Chain
 from langchain_core.callbacks import CallbackManagerForChainRun
-from langchain_core.pydantic_v1 import Extra, Field, root_validator
+from pydantic import ConfigDict, Field, model_validator
 
 from langchain_community.utilities.requests import TextRequestsWrapper
 
@@ -28,7 +28,7 @@ class LLMRequestsChain(Chain):
         See https://python.langchain.com/docs/security for more information.
     """
 
-    llm_chain: LLMChain  # type: ignore[valid-type]
+    llm_chain: LLMChain
     requests_wrapper: TextRequestsWrapper = Field(
         default_factory=lambda: TextRequestsWrapper(headers=DEFAULT_HEADERS),
         exclude=True,
@@ -38,11 +38,10 @@ class LLMRequestsChain(Chain):
     input_key: str = "url"  #: :meta private:
     output_key: str = "output"  #: :meta private:
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        extra = Extra.forbid
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(
+        arbitrary_types_allowed=True,
+        extra="forbid",
+    )
 
     @property
     def input_keys(self) -> List[str]:
@@ -60,8 +59,9 @@ class LLMRequestsChain(Chain):
         """
         return [self.output_key]
 
-    @root_validator(pre=True)
-    def validate_environment(cls, values: Dict) -> Dict:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_environment(cls, values: Dict) -> Any:
         """Validate that api key and python package exists in environment."""
         try:
             from bs4 import BeautifulSoup  # noqa: F401
@@ -88,7 +88,7 @@ class LLMRequestsChain(Chain):
         # extract the text from the html
         soup = BeautifulSoup(res, "html.parser")
         other_keys[self.requests_key] = soup.get_text()[: self.text_length]
-        result = self.llm_chain.predict(  # type: ignore[attr-defined]
+        result = self.llm_chain.predict(
             callbacks=_run_manager.get_child(), **other_keys
         )
         return {self.output_key: result}
