@@ -25,7 +25,8 @@ from langchain_core.outputs import (
     ChatResult,
     LLMResult,
 )
-from langchain_core.pydantic_v1 import root_validator
+from pydantic import model_validator
+from typing_extensions import Self
 
 from langchain_community.llms.huggingface_endpoint import HuggingFaceEndpoint
 from langchain_community.llms.huggingface_hub import HuggingFaceHub
@@ -38,7 +39,7 @@ DEFAULT_SYSTEM_PROMPT = """You are a helpful, respectful, and honest assistant."
 
 @deprecated(
     since="0.0.37",
-    removal="0.3",
+    removal="1.0",
     alternative_import="langchain_huggingface.ChatHuggingFace",
 )
 class ChatHuggingFace(BaseChatModel):
@@ -76,17 +77,17 @@ class ChatHuggingFace(BaseChatModel):
             else self.tokenizer
         )
 
-    @root_validator(pre=False, skip_on_failure=True)
-    def validate_llm(cls, values: dict) -> dict:
+    @model_validator(mode="after")
+    def validate_llm(self) -> Self:
         if not isinstance(
-            values["llm"],
+            self.llm,
             (HuggingFaceTextGenInference, HuggingFaceEndpoint, HuggingFaceHub),
         ):
             raise TypeError(
                 "Expected llm to be one of HuggingFaceTextGenInference, "
-                f"HuggingFaceEndpoint, HuggingFaceHub, received {type(values['llm'])}"
+                f"HuggingFaceEndpoint, HuggingFaceHub, received {type(self.llm)}"
             )
-        return values
+        return self
 
     def _stream(
         self,
