@@ -21,8 +21,8 @@ from langchain_core.messages import (
     SystemMessage,
 )
 from langchain_core.outputs import ChatGeneration, ChatGenerationChunk, ChatResult
-from langchain_core.pydantic_v1 import root_validator
 from langchain_core.utils import get_pydantic_field_names
+from pydantic import ConfigDict, model_validator
 
 logger = logging.getLogger(__name__)
 
@@ -84,13 +84,13 @@ class LlamaEdgeChatService(BaseChatModel):
     streaming: bool = False
     """Whether to stream the results or not."""
 
-    class Config:
-        """Configuration for this pydantic object."""
+    model_config = ConfigDict(
+        populate_by_name=True,
+    )
 
-        allow_population_by_field_name = True
-
-    @root_validator(pre=True)
-    def build_extra(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+    @model_validator(mode="before")
+    @classmethod
+    def build_extra(cls, values: Dict[str, Any]) -> Any:
         """Build extra kwargs from additional params that were passed in."""
         all_required_field_names = get_pydantic_field_names(cls)
         extra = values.get("model_kwargs", {})
@@ -146,7 +146,7 @@ class LlamaEdgeChatService(BaseChatModel):
     ) -> Iterator[ChatGenerationChunk]:
         res = self._chat(messages, **kwargs)
 
-        default_chunk_class = AIMessageChunk
+        default_chunk_class: Type[BaseMessageChunk] = AIMessageChunk
         substring = '"object":"chat.completion.chunk"}'
         for line in res.iter_lines():
             chunks = []
