@@ -12,6 +12,7 @@ from typing import (
     Iterator,
     List,
     Optional,
+    Sequence,
     Tuple,
     Type,
     Union,
@@ -20,6 +21,7 @@ from typing import (
 from langchain_core.callbacks import (
     CallbackManagerForLLMRun,
 )
+from langchain_core.language_models import LanguageModelInput
 from langchain_core.language_models.chat_models import BaseChatModel
 from langchain_core.language_models.llms import create_base_retry_decorator
 from langchain_core.messages import (
@@ -33,15 +35,19 @@ from langchain_core.messages import (
     HumanMessageChunk,
     SystemMessage,
     SystemMessageChunk,
+    ToolMessage,
 )
 from langchain_core.outputs import ChatGeneration, ChatGenerationChunk, ChatResult
-from langchain_core.pydantic_v1 import (
+from langchain_core.runnables import Runnable
+from langchain_core.tools import BaseTool
+from langchain_core.utils import get_from_dict_or_env, pre_init
+from langchain_core.utils.function_calling import convert_to_openai_tool
+from pydantic import (
     BaseModel,
-    Extra,
+    ConfigDict,
     Field,
     SecretStr,
 )
-from langchain_core.utils import get_from_dict_or_env, pre_init
 
 if TYPE_CHECKING:
     from premai.api.chat_completions.v1_chat_completions_create import (
@@ -51,6 +57,19 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger(__name__)
 
+TOOL_PROMPT_HEADER = """
+Given the set of tools you used and the response, provide the final answer\n
+"""
+
+INTERMEDIATE_TOOL_RESULT_TEMPLATE = """
+{json}
+"""
+
+SINGLE_TOOL_PROMPT_TEMPLATE = """
+tool id: {tool_id}
+tool_response: {tool_response}
+"""
+
 
 class ChatPremAPIError(Exception):
     """Error with the `PremAI` API."""
@@ -91,8 +110,22 @@ def _response_to_result(
             raise ChatPremAPIError(f"ChatResponse must have a content: {content}")
 
         if role == "assistant":
+            tool_calls = choice.message["tool_calls"]
+            if tool_calls is None:
+                tools = []
+            else:
+                tools = [
+                    {
+                        "id": tool_call["id"],
+                        "name": tool_call["function"]["name"],
+                        "args": tool_call["function"]["arguments"],
+                    }
+                    for tool_call in tool_calls
+                ]
             generations.append(
-                ChatGeneration(text=content, message=AIMessage(content=content))
+                ChatGeneration(
+                    text=content, message=AIMessage(content=content, tool_calls=tools)
+                )
             )
         elif role == "user":
             generations.append(
@@ -125,9 +158,9 @@ def _convert_delta_response_to_message_chunk(
     Optional[str],
 ]:
     """Converts delta response to message chunk"""
-    _delta = response.choices[0].delta  # type: ignore
-    role = _delta.get("role", "")  # type: ignore
-    content = _delta.get("content", "")  # type: ignore
+    _delta = response.choices[0].delta
+    role = _delta.get("role", "")
+    content = _delta.get("content", "")
     additional_kwargs: Dict = {}
     finish_reasons: Optional[str] = response.choices[0].finish_reason
 
@@ -156,41 +189,75 @@ def _messages_to_prompt_dict(
     system_prompt: Optional[str] = None
     examples_and_messages: List[Dict[str, Any]] = []
 
-    if template_id is not None:
-        params: Dict[str, str] = {}
-        for input_msg in input_messages:
-            if isinstance(input_msg, SystemMessage):
-                system_prompt = str(input_msg.content)
+    for input_msg in input_messages:
+        if isinstance(input_msg, SystemMessage):
+            system_prompt = str(input_msg.content)
+
+        elif isinstance(input_msg, HumanMessage):
+            if template_id is None:
+                examples_and_messages.append(
+                    {
+                        "role": "user",
+                        "content": str(input_msg.content),
+                    }
+                )
             else:
+                params: Dict[str, str] = {}
                 assert (input_msg.id is not None) and (input_msg.id != ""), ValueError(
                     "When using prompt template there should be id associated ",
                     "with each HumanMessage",
                 )
                 params[str(input_msg.id)] = str(input_msg.content)
-
-        examples_and_messages.append(
-            {"role": "user", "template_id": template_id, "params": params}
-        )
-
-        for input_msg in input_messages:
-            if isinstance(input_msg, AIMessage):
                 examples_and_messages.append(
-                    {"role": "assistant", "content": str(input_msg.content)}
+                    {
+                        "role": "user",
+                        "template_id": template_id,
+                        "params": params,
+                    }
                 )
-    else:
-        for input_msg in input_messages:
-            if isinstance(input_msg, SystemMessage):
-                system_prompt = str(input_msg.content)
-            elif isinstance(input_msg, HumanMessage):
+        elif isinstance(input_msg, AIMessage):
+            if input_msg.tool_calls is None or len(input_msg.tool_calls) == 0:
                 examples_and_messages.append(
-                    {"role": "user", "content": str(input_msg.content)}
-                )
-            elif isinstance(input_msg, AIMessage):
-                examples_and_messages.append(
-                    {"role": "assistant", "content": str(input_msg.content)}
+                    {
+                        "role": "assistant",
+                        "content": str(input_msg.content),
+                    }
                 )
             else:
-                raise ChatPremAPIError("No such role explicitly exists")
+                ai_msg_to_json = {
+                    "id": input_msg.id,
+                    "content": input_msg.content,
+                    "response_metadata": input_msg.response_metadata,
+                    "tool_calls": input_msg.tool_calls,
+                }
+                examples_and_messages.append(
+                    {
+                        "role": "assistant",
+                        "content": INTERMEDIATE_TOOL_RESULT_TEMPLATE.format(
+                            json=ai_msg_to_json,
+                        ),
+                    }
+                )
+        elif isinstance(input_msg, ToolMessage):
+            pass
+
+        else:
+            raise ChatPremAPIError("No such role explicitly exists")
+
+    # do a separate search for tool calls
+    tool_prompt = ""
+    for input_msg in input_messages:
+        if isinstance(input_msg, ToolMessage):
+            tool_id = input_msg.tool_call_id
+            tool_result = input_msg.content
+            tool_prompt += SINGLE_TOOL_PROMPT_TEMPLATE.format(
+                tool_id=tool_id, tool_response=tool_result
+            )
+    if tool_prompt != "":
+        prompt = TOOL_PROMPT_HEADER
+        prompt += tool_prompt
+        examples_and_messages.append({"role": "user", "content": prompt})
+
     return system_prompt, examples_and_messages
 
 
@@ -215,13 +282,22 @@ class ChatPremAI(BaseChatModel, BaseModel):
     If model name is other than default model then it will override the calls 
     from the model deployed from launchpad."""
 
-    temperature: Optional[float] = None
+    session_id: Optional[str] = None
+    """The ID of the session to use. It helps to track the chat history."""
+
+    temperature: Optional[float] = Field(default=None)
     """Model temperature. Value should be >= 0 and <= 1.0"""
 
-    max_tokens: Optional[int] = None
+    top_p: Optional[float] = None
+    """top_p adjusts the number of choices for each predicted tokens based on
+        cumulative probabilities. Value should be ranging between 0.0 and 1.0. 
+    """
+
+    max_tokens: Optional[int] = Field(default=None)
+
     """The maximum number of tokens to generate"""
 
-    max_retries: int = 1
+    max_retries: int = Field(default=1)
     """Max number of retries to call the API"""
 
     system_prompt: Optional[str] = ""
@@ -239,14 +315,13 @@ class ChatPremAI(BaseChatModel, BaseModel):
     streaming: Optional[bool] = False
     """Whether to stream the responses or not."""
 
-    client: Any
+    client: Any = None
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        extra = Extra.forbid
-        allow_population_by_field_name = True
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(
+        populate_by_name=True,
+        arbitrary_types_allowed=True,
+        extra="forbid",
+    )
 
     @pre_init
     def validate_environments(cls, values: Dict) -> Dict:
@@ -289,7 +364,6 @@ class ChatPremAI(BaseChatModel, BaseModel):
     def _get_all_kwargs(self, **kwargs: Any) -> Dict[str, Any]:
         kwargs_to_ignore = [
             "top_p",
-            "tools",
             "frequency_penalty",
             "presence_penalty",
             "logit_bias",
@@ -324,7 +398,7 @@ class ChatPremAI(BaseChatModel, BaseModel):
                 messages, template_id=kwargs["template_id"]
             )
         else:
-            system_prompt, messages_to_pass = _messages_to_prompt_dict(messages)  # type: ignore
+            system_prompt, messages_to_pass = _messages_to_prompt_dict(messages)
 
         if system_prompt is not None and system_prompt != "":
             kwargs["system_prompt"] = system_prompt
@@ -351,9 +425,9 @@ class ChatPremAI(BaseChatModel, BaseModel):
         if "template_id" in kwargs:
             system_prompt, messages_to_pass = _messages_to_prompt_dict(
                 messages, template_id=kwargs["template_id"]
-            )  # type: ignore
+            )
         else:
-            system_prompt, messages_to_pass = _messages_to_prompt_dict(messages)  # type: ignore
+            system_prompt, messages_to_pass = _messages_to_prompt_dict(messages)
 
         if stop is not None:
             logger.warning("stop is not supported in langchain streaming")
@@ -392,6 +466,14 @@ class ChatPremAI(BaseChatModel, BaseModel):
             except Exception as _:
                 continue
 
+    def bind_tools(
+        self,
+        tools: Sequence[Union[Dict[str, Any], Type[BaseModel], Callable, BaseTool]],
+        **kwargs: Any,
+    ) -> Runnable[LanguageModelInput, BaseMessage]:
+        formatted_tools = [convert_to_openai_tool(tool) for tool in tools]
+        return super().bind(tools=formatted_tools, **kwargs)
+
 
 def create_prem_retry_decorator(
     llm: ChatPremAI,
