@@ -3,15 +3,15 @@
 from typing import Dict
 
 from langchain_core._api import deprecated
-from langchain_core.pydantic_v1 import Field
 from langchain_core.utils import get_from_dict_or_env, pre_init
+from pydantic import ConfigDict, Field
 
 from langchain_community.chat_models import ChatOpenAI
 from langchain_community.llms.solar import SOLAR_SERVICE_URL_BASE, SolarCommon
 
 
 @deprecated(  # type: ignore[arg-type]
-    since="0.0.34", removal="0.3.0", alternative_import="langchain_upstage.ChatUpstage"
+    since="0.0.34", removal="1.0", alternative_import="langchain_upstage.ChatUpstage"
 )
 class SolarChat(SolarCommon, ChatOpenAI):
     """Wrapper around Solar large language models.
@@ -24,18 +24,17 @@ class SolarChat(SolarCommon, ChatOpenAI):
 
             from langchain_community.chat_models.solar import SolarChat
 
-            solar = SolarChat(model="solar-1-mini-chat")
+            solar = SolarChat(model="solar-mini")
     """
 
     max_tokens: int = Field(default=1024)
 
     # this is needed to match ChatOpenAI superclass
-    class Config:
-        """Configuration for this pydantic object."""
-
-        allow_population_by_field_name = True
-        arbitrary_types_allowed = True
-        extra = "ignore"
+    model_config = ConfigDict(
+        populate_by_name=True,
+        arbitrary_types_allowed=True,
+        extra="ignore",
+    )
 
     @pre_init
     def validate_environment(cls, values: Dict) -> Dict:
