@@ -1,4 +1,5 @@
 import json
+from os import PathLike
 from pathlib import Path
 from typing import Any, Callable, Dict, Iterator, Optional, Union
 
@@ -82,7 +83,7 @@ class JSONLoader(BaseLoader):
 
     def __init__(
         self,
-        file_path: Union[str, Path],
+        file_path: Union[str, PathLike],
         jq_schema: str,
         content_key: Optional[str] = None,
         is_content_key_jq_parsable: Optional[bool] = False,
@@ -93,7 +94,7 @@ class JSONLoader(BaseLoader):
         """Initialize the JSONLoader.
 
         Args:
-            file_path (Union[str, Path]): The path to the JSON or JSON Lines file.
+            file_path (Union[str, PathLike]): The path to the JSON or JSON Lines file.
             jq_schema (str): The jq schema to use to extract the data or text from
                 the JSON.
             content_key (str): The key to use to extract the content from
@@ -135,7 +136,7 @@ class JSONLoader(BaseLoader):
         """Load and return documents from the JSON file."""
         index = 0
         if self._json_lines:
-            with self.file_path.open(encoding="utf-8") as f:
+            with self.file_path.open(encoding="utf-8-sig") as f:
                 for line in f:
                     line = line.strip()
                     if line:
@@ -143,7 +144,9 @@ class JSONLoader(BaseLoader):
                             yield doc
                             index += 1
         else:
-            for doc in self._parse(self.file_path.read_text(encoding="utf-8"), index):
+            for doc in self._parse(
+                self.file_path.read_text(encoding="utf-8-sig"), index
+            ):
                 yield doc
                 index += 1
 
@@ -156,8 +159,6 @@ class JSONLoader(BaseLoader):
         # and prevent the user from getting a cryptic error later on.
         if self._content_key is not None:
             self._validate_content_key(data)
-        if self._metadata_func is not None:
-            self._validate_metadata_func(data)
 
         for i, sample in enumerate(data, index + 1):
             text = self._get_text(sample=sample)
@@ -177,7 +178,7 @@ class JSONLoader(BaseLoader):
         else:
             content = sample
 
-        if self._text_content and not isinstance(content, str):
+        if self._text_content and not isinstance(content, str) and content is not None:
             raise ValueError(
                 f"Expected page_content is string, got {type(content)} instead. \
                     Set `text_content=False` if the desired input for \
@@ -187,7 +188,7 @@ class JSONLoader(BaseLoader):
         # In case the text is None, set it to an empty string
         elif isinstance(content, str):
             return content
-        elif isinstance(content, dict):
+        elif isinstance(content, (dict, list)):
             return json.dumps(content) if content else ""
         else:
             return str(content) if content is not None else ""
@@ -202,7 +203,13 @@ class JSONLoader(BaseLoader):
         :return:
         """
         if self._metadata_func is not None:
-            return self._metadata_func(sample, additional_fields)
+            result = self._metadata_func(sample, additional_fields)
+            if not isinstance(result, dict):
+                raise ValueError(
+                    f"Expected the metadata_func to return a dict but got \
+                                `{type(result)}`"
+                )
+            return result
         else:
             return additional_fields
 
@@ -232,15 +239,3 @@ class JSONLoader(BaseLoader):
                 f"Expected the jq schema to result in a list of objects (dict) \
                     with the key `{self._content_key}` which should be parsable by jq"
             )
-
-    def _validate_metadata_func(self, data: Any) -> None:
-        """Check if the metadata_func output is valid"""
-
-        sample = data.first()
-        if self._metadata_func is not None:
-            sample_metadata = self._metadata_func(sample, {})
-            if not isinstance(sample_metadata, dict):
-                raise ValueError(
-                    f"Expected the metadata_func to return a dict but got \
-                        `{type(sample_metadata)}`"
-                )
