@@ -10,8 +10,8 @@ from urllib.parse import parse_qs, urlparse
 from xml.etree.ElementTree import ParseError  # OK: trusted-source
 
 from langchain_core.documents import Document
-from langchain_core.pydantic_v1 import root_validator
-from langchain_core.pydantic_v1.dataclasses import dataclass
+from pydantic import model_validator
+from pydantic.dataclasses import dataclass
 
 from langchain_community.document_loaders.base import BaseLoader
 
@@ -50,17 +50,16 @@ class GoogleApiClient:
     def __post_init__(self) -> None:
         self.creds = self._load_credentials()
 
-    @root_validator(pre=True)
-    def validate_channel_or_videoIds_is_set(
-        cls, values: Dict[str, Any]
-    ) -> Dict[str, Any]:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_channel_or_videoIds_is_set(cls, values: Any) -> Any:
         """Validate that either folder_id or document_ids is set, but not both."""
 
-        if not values.get("credentials_path") and not values.get(
+        if not values.kwargs.get("credentials_path") and not values.kwargs.get(
             "service_account_path"
         ):
             raise ValueError("Must specify either channel_name or video_ids")
-        return values
+        return values.kwargs
 
     def _load_credentials(self) -> Any:
         """Load credentials."""
@@ -242,6 +241,7 @@ class YoutubeLoader(BaseLoader):
         """Load YouTube transcripts into `Document` objects."""
         try:
             from youtube_transcript_api import (
+                FetchedTranscript,
                 NoTranscriptFound,
                 TranscriptsDisabled,
                 YouTubeTranscriptApi,
@@ -270,8 +270,18 @@ class YoutubeLoader(BaseLoader):
 
         if self.translation is not None:
             transcript = transcript.translate(self.translation)
-
-        transcript_pieces: List[Dict[str, Any]] = transcript.fetch()
+        transcript_object = transcript.fetch()
+        if isinstance(transcript_object, FetchedTranscript):
+            transcript_pieces = [
+                {
+                    "text": snippet.text,
+                    "start": snippet.start,
+                    "duration": snippet.duration,
+                }
+                for snippet in transcript_object.snippets
+            ]
+        else:
+            transcript_pieces: List[Dict[str, Any]] = transcript_object  # type: ignore[no-redef]
 
         if self.transcript_format == TranscriptFormat.TEXT:
             transcript = " ".join(
@@ -391,14 +401,13 @@ class GoogleApiYoutubeLoader(BaseLoader):
 
         return build("youtube", "v3", credentials=creds)
 
-    @root_validator(pre=True)
-    def validate_channel_or_videoIds_is_set(
-        cls, values: Dict[str, Any]
-    ) -> Dict[str, Any]:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_channel_or_videoIds_is_set(cls, values: Any) -> Any:
         """Validate that either folder_id or document_ids is set, but not both."""
-        if not values.get("channel_name") and not values.get("video_ids"):
+        if not values.kwargs.get("channel_name") and not values.kwargs.get("video_ids"):
             raise ValueError("Must specify either channel_name or video_ids")
-        return values
+        return values.kwargs
 
     def _get_transcripe_for_video_id(self, video_id: str) -> str:
         from youtube_transcript_api import NoTranscriptFound, YouTubeTranscriptApi
