@@ -7,8 +7,8 @@ import time
 from typing import Any, Callable, Dict, List, Sequence
 
 from langchain_core.embeddings import Embeddings
-from langchain_core.pydantic_v1 import BaseModel, Field, SecretStr
 from langchain_core.utils import convert_to_secret_str, get_from_dict_or_env, pre_init
+from pydantic import BaseModel, ConfigDict, Field, SecretStr
 from tenacity import (
     before_sleep_log,
     retry,
@@ -69,12 +69,9 @@ class YandexGPTEmbeddings(BaseModel, Embeddings):
     disable_request_logging: bool = False
     """YandexGPT API logs all request data by default. 
     If you provide personal data, confidential information, disable logging."""
-    _grpc_metadata: Sequence
+    grpc_metadata: Sequence
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        allow_population_by_field_name = True
+    model_config = ConfigDict(populate_by_name=True, protected_namespaces=())
 
     @pre_init
     def validate_environment(cls, values: Dict) -> Dict:
@@ -93,15 +90,15 @@ class YandexGPTEmbeddings(BaseModel, Embeddings):
         if api_key.get_secret_value() == "" and iam_token.get_secret_value() == "":
             raise ValueError("Either 'YC_API_KEY' or 'YC_IAM_TOKEN' must be provided.")
         if values["iam_token"]:
-            values["_grpc_metadata"] = [
+            values["grpc_metadata"] = [
                 ("authorization", f"Bearer {values['iam_token'].get_secret_value()}")
             ]
             if values["folder_id"]:
-                values["_grpc_metadata"].append(("x-folder-id", values["folder_id"]))
+                values["grpc_metadata"].append(("x-folder-id", values["folder_id"]))
         else:
-            values["_grpc_metadata"] = (
+            values["grpc_metadata"] = [
                 ("authorization", f"Api-Key {values['api_key'].get_secret_value()}"),
-            )
+            ]
 
         if not values.get("doc_model_uri"):
             if values["folder_id"] == "":
@@ -116,7 +113,7 @@ class YandexGPTEmbeddings(BaseModel, Embeddings):
                 f"emb://{values['folder_id']}/{values['model_name']}/{values['model_version']}"
             )
         if values["disable_request_logging"]:
-            values["_grpc_metadata"].append(
+            values["grpc_metadata"].append(
                 (
                     "x-data-logging-enabled",
                     "false",
@@ -162,18 +159,20 @@ def _create_retry_decorator(llm: YandexGPTEmbeddings) -> Callable[[Any], Any]:
     )
 
 
-def _embed_with_retry(llm: YandexGPTEmbeddings, **kwargs: Any) -> Any:
+def _embed_with_retry(llm: YandexGPTEmbeddings, **kwargs: Any) -> list[list[float]]:
     """Use tenacity to retry the embedding call."""
     retry_decorator = _create_retry_decorator(llm)
 
     @retry_decorator
-    def _completion_with_retry(**_kwargs: Any) -> Any:
+    def _completion_with_retry(**_kwargs: Any) -> list[list[float]]:
         return _make_request(llm, **_kwargs)
 
     return _completion_with_retry(**kwargs)
 
 
-def _make_request(self: YandexGPTEmbeddings, texts: List[str], **kwargs):  # type: ignore[no-untyped-def]
+def _make_request(
+    self: YandexGPTEmbeddings, texts: List[str], **kwargs: Any
+) -> list[list[float]]:
     try:
         import grpc
 
@@ -208,7 +207,7 @@ def _make_request(self: YandexGPTEmbeddings, texts: List[str], **kwargs):  # typ
     for text in texts:
         request = TextEmbeddingRequest(model_uri=model_uri, text=text)
         stub = EmbeddingsServiceStub(channel)
-        res = stub.TextEmbedding(request, metadata=self._grpc_metadata)  # type: ignore[attr-defined]
+        res = stub.TextEmbedding(request, metadata=self.grpc_metadata)
         result.append(list(res.embedding))
         time.sleep(self.sleep_interval)
 
