@@ -9,9 +9,9 @@ from langchain_core.callbacks import (
 )
 from langchain_core.language_models.llms import BaseLLM, create_base_retry_decorator
 from langchain_core.outputs import Generation, GenerationChunk, LLMResult
-from langchain_core.pydantic_v1 import Field, SecretStr
 from langchain_core.utils import convert_to_secret_str, pre_init
 from langchain_core.utils.env import get_from_dict_or_env
+from pydantic import Field, SecretStr
 
 
 def _stream_response_to_generation_chunk(
@@ -29,7 +29,7 @@ def _stream_response_to_generation_chunk(
 
 @deprecated(
     since="0.0.26",
-    removal="0.3",
+    removal="1.0",
     alternative_import="langchain_fireworks.Fireworks",
 )
 class Fireworks(BaseLLM):
