@@ -1,8 +1,22 @@
+from __future__ import annotations
+
 import json
-from typing import Any, AsyncIterator, Dict, Iterator, List, Mapping, Optional, Union
+from typing import (
+    Any,
+    AsyncIterator,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Mapping,
+    Optional,
+    Tuple,
+    Union,
+)
 
 import aiohttp
 import requests
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import (
     AsyncCallbackManagerForLLMRun,
     CallbackManagerForLLMRun,
@@ -10,7 +24,7 @@ from langchain_core.callbacks import (
 from langchain_core.language_models import BaseLanguageModel
 from langchain_core.language_models.llms import BaseLLM
 from langchain_core.outputs import GenerationChunk, LLMResult
-from langchain_core.pydantic_v1 import Extra
+from pydantic import ConfigDict
 
 
 def _stream_response_to_generation_chunk(
@@ -132,6 +146,10 @@ class _OllamaCommon(BaseLanguageModel):
     tokens for authentication.
     """
 
+    auth: Union[Callable, Tuple, None] = None
+    """Additional auth tuple or callable to enable Basic/Digest/Custom HTTP Auth.
+    Expects the same format, type and values as requests.request auth parameter."""
+
     @property
     def _default_params(self) -> Dict[str, Any]:
         """Get the default parameters for calling Ollama."""
@@ -237,6 +255,7 @@ class _OllamaCommon(BaseLanguageModel):
                 "Content-Type": "application/json",
                 **(self.headers if isinstance(self.headers, dict) else {}),
             },
+            auth=self.auth,
             json=request_payload,
             stream=True,
             timeout=self.timeout,
@@ -300,8 +319,9 @@ class _OllamaCommon(BaseLanguageModel):
                     "Content-Type": "application/json",
                     **(self.headers if isinstance(self.headers, dict) else {}),
                 },
+                auth=self.auth,  # type: ignore[arg-type,unused-ignore]
                 json=request_payload,
-                timeout=self.timeout,
+                timeout=self.timeout,  # type: ignore[arg-type,unused-ignore]
             ) as response:
                 if response.status != 200:
                     if response.status == 404:
@@ -370,6 +390,11 @@ class _OllamaCommon(BaseLanguageModel):
         return final_chunk
 
 
+@deprecated(
+    since="0.3.1",
+    removal="1.0.0",
+    alternative_import="langchain_ollama.OllamaLLM",
+)
 class Ollama(BaseLLM, _OllamaCommon):
     """Ollama locally runs large language models.
     To use, follow the instructions at https://ollama.ai/.
@@ -379,10 +404,9 @@ class Ollama(BaseLLM, _OllamaCommon):
             ollama = Ollama(model="llama2")
     """
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        extra = Extra.forbid
+    model_config = ConfigDict(
+        extra="forbid",
+    )
 
     @property
     def _llm_type(self) -> str:
