@@ -3,8 +3,14 @@ from typing import Any, Dict, List, Optional
 import requests
 from langchain_core.callbacks import CallbackManagerForLLMRun
 from langchain_core.language_models import LLM
-from langchain_core.pydantic_v1 import BaseModel, Field, SecretStr, root_validator
 from langchain_core.utils import convert_to_secret_str, get_from_dict_or_env, pre_init
+from pydantic import (
+    BaseModel,
+    ConfigDict,
+    Field,
+    SecretStr,
+    model_validator,
+)
 
 from langchain_community.llms.utils import enforce_stop_tokens
 
@@ -38,15 +44,17 @@ class SolarCommon(BaseModel):
     base_url: str = SOLAR_SERVICE_URL_BASE
     solar_api_key: Optional[SecretStr] = Field(default=None, alias="api_key")
     """Solar API key. Get it here: https://console.upstage.ai/services/solar"""
-    model_name: str = Field(default="solar-1-mini-chat", alias="model")
+    model_name: str = Field(default="solar-mini", alias="model")
     """Model name. Available models listed here: https://console.upstage.ai/services/solar"""
     max_tokens: int = Field(default=1024)
-    temperature = 0.3
+    temperature: float = 0.3
 
-    class Config:
-        allow_population_by_field_name = True
-        arbitrary_types_allowed = True
-        extra = "ignore"
+    model_config = ConfigDict(
+        populate_by_name=True,
+        arbitrary_types_allowed=True,
+        extra="ignore",
+        protected_namespaces=(),
+    )
 
     @property
     def lc_secrets(self) -> dict:
@@ -64,8 +72,9 @@ class SolarCommon(BaseModel):
     def _invocation_params(self) -> Dict[str, Any]:
         return {**{"model": self.model_name}, **self._default_params}
 
-    @root_validator(pre=True)
-    def build_extra(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+    @model_validator(mode="before")
+    @classmethod
+    def build_extra(cls, values: Dict[str, Any]) -> Any:
         return values
 
     @pre_init
@@ -100,8 +109,9 @@ class Solar(SolarCommon, LLM):
     Referenced from https://console.upstage.ai/services/solar
     """
 
-    class Config:
-        allow_population_by_field_name = True
+    model_config = ConfigDict(
+        populate_by_name=True,
+    )
 
     def _call(
         self,
