@@ -9,7 +9,7 @@ from langchain_core.callbacks import (
 )
 from langchain_core.language_models.llms import LLM
 from langchain_core.outputs import GenerationChunk
-from langchain_core.pydantic_v1 import Field
+from pydantic import Field
 
 logger = logging.getLogger(__name__)
 
@@ -330,19 +330,18 @@ class TextGen(LLM):
             result = websocket_client.recv()
             result = json.loads(result)
 
-            if result["event"] == "text_stream":  # type: ignore[call-overload, index]
+            if result["event"] == "text_stream":
                 chunk = GenerationChunk(
-                    text=result["text"],  # type: ignore[call-overload, index]
+                    text=result["text"],
                     generation_info=None,
                 )
+                if run_manager:
+                    run_manager.on_llm_new_token(token=chunk.text)
                 yield chunk
-            elif result["event"] == "stream_end":  # type: ignore[call-overload, index]
+            elif result["event"] == "stream_end":
                 websocket_client.close()
                 return
 
-            if run_manager:
-                run_manager.on_llm_new_token(token=chunk.text)
-
     async def _astream(
         self,
         prompt: str,
@@ -403,15 +402,14 @@ class TextGen(LLM):
             result = websocket_client.recv()
             result = json.loads(result)
 
-            if result["event"] == "text_stream":  # type: ignore[call-overload, index]
+            if result["event"] == "text_stream":
                 chunk = GenerationChunk(
-                    text=result["text"],  # type: ignore[call-overload, index]
+                    text=result["text"],
                     generation_info=None,
                 )
+                if run_manager:
+                    await run_manager.on_llm_new_token(token=chunk.text)
                 yield chunk
-            elif result["event"] == "stream_end":  # type: ignore[call-overload, index]
+            elif result["event"] == "stream_end":
                 websocket_client.close()
                 return
-
-            if run_manager:
-                await run_manager.on_llm_new_token(token=chunk.text)
