@@ -11,8 +11,8 @@ To use this tool, you must first set as environment variables:
 from typing import Optional
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import Field
 from langchain_core.tools import BaseTool
+from pydantic import Field
 
 from langchain_community.utilities.gitlab import GitLabAPIWrapper
 
@@ -20,7 +20,7 @@ from langchain_community.utilities.gitlab import GitLabAPIWrapper
 class GitLabAction(BaseTool):
     """Tool for interacting with the GitLab API."""
 
-    api_wrapper: GitLabAPIWrapper = Field(default_factory=GitLabAPIWrapper)  # type: ignore[arg-type]
+    api_wrapper: GitLabAPIWrapper = Field(default_factory=GitLabAPIWrapper)
     mode: str
     name: str = ""
     description: str = ""
