@@ -4,7 +4,7 @@ from enum import Enum
 from typing import Any, Dict, List, Optional, Type
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import BaseModel, Field
+from pydantic import BaseModel, Field
 
 from langchain_community.tools.gmail.base import GmailBaseTool
 from langchain_community.tools.gmail.utils import clean_email_body
