@@ -6,7 +6,7 @@ from email.mime.text import MIMEText
 from typing import Any, Dict, List, Optional, Type, Union
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import BaseModel, Field
+from pydantic import BaseModel, Field
 
 from langchain_community.tools.gmail.base import GmailBaseTool
 
@@ -41,7 +41,7 @@ class GmailSendMessage(GmailBaseTool):
 
     name: str = "send_gmail_message"
     description: str = (
-        "Use this tool to send email messages." " The input is the message, recipients"
+        "Use this tool to send email messages. The input is the message, recipients"
     )
     args_schema: Type[SendMessageSchema] = SendMessageSchema
 
@@ -86,6 +86,6 @@ class GmailSendMessage(GmailBaseTool):
                 .send(userId="me", body=create_message)
             )
             sent_message = send_message.execute()
-            return f'Message sent. Message Id: {sent_message["id"]}'
+            return f"Message sent. Message Id: {sent_message['id']}"
         except Exception as error:
             raise Exception(f"An error occurred: {error}")
