@@ -4,8 +4,8 @@ from typing import Optional, Type
 
 from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import BaseModel, Field
 from langchain_core.tools import BaseTool
+from pydantic import BaseModel, Field
 
 from langchain_community.utilities.google_places_api import GooglePlacesAPIWrapper
 
@@ -18,7 +18,7 @@ class GooglePlacesSchema(BaseModel):
 
 @deprecated(
     since="0.0.33",
-    removal="0.3.0",
+    removal="1.0",
     alternative_import="langchain_google_community.GooglePlacesTool",
 )
 class GooglePlacesTool(BaseTool):
@@ -31,7 +31,7 @@ class GooglePlacesTool(BaseTool):
         "discover addressed from ambiguous text. "
         "Input should be a search query."
     )
-    api_wrapper: GooglePlacesAPIWrapper = Field(default_factory=GooglePlacesAPIWrapper)  # type: ignore[arg-type]
+    api_wrapper: GooglePlacesAPIWrapper = Field(default_factory=GooglePlacesAPIWrapper)
     args_schema: Type[BaseModel] = GooglePlacesSchema
 
     def _run(
