@@ -3,13 +3,13 @@
 from typing import Callable, Optional
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import Field
 from langchain_core.tools import BaseTool
+from pydantic import Field
 
 
 def _print_func(text: str) -> None:
-    print("\n")
-    print(text)
+    print("\n")  # noqa: T201
+    print(text)  # noqa: T201
 
 
 class HumanInputRun(BaseTool):
