@@ -6,8 +6,8 @@ the the NASA Image & Video Library and Exoplanet
 from typing import Optional
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import Field
 from langchain_core.tools import BaseTool
+from pydantic import Field
 
 from langchain_community.utilities.nasa import NasaAPIWrapper
 
