@@ -8,7 +8,7 @@ from datetime import datetime as dt
 from typing import Any, Dict, List, Optional, Type
 
 from langchain_core.callbacks import CallbackManagerForToolRun
-from langchain_core.pydantic_v1 import BaseModel, Extra, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 from langchain_community.tools.office365.base import O365BaseTool
 from langchain_community.tools.office365.utils import UTC_FORMAT, clean_body
@@ -70,10 +70,9 @@ class O365SearchEvents(O365BaseTool):
         "is busy during meetings. Any times without events are free for the user. "
     )
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        extra = Extra.forbid
+    model_config = ConfigDict(
+        extra="forbid",
+    )
 
     def _run(
         self,
