@@ -11,7 +11,7 @@ from langchain_community.utilities.stackexchange import StackExchangeAPIWrapper
 class StackExchangeTool(BaseTool):
     """Tool that uses StackExchange"""
 
-    name: str = "StackExchange"
+    name: str = "stack_exchange"
     description: str = (
         "A wrapper around StackExchange. "
         "Useful for when you need to answer specific programming questions"
