@@ -1,13 +1,14 @@
 """Tool for the Tavily search API."""
 
-from typing import Dict, List, Optional, Type, Union
+from typing import Any, Dict, List, Literal, Optional, Tuple, Type, Union
 
+from langchain_core._api import deprecated
 from langchain_core.callbacks import (
     AsyncCallbackManagerForToolRun,
     CallbackManagerForToolRun,
 )
-from langchain_core.pydantic_v1 import BaseModel, Field
 from langchain_core.tools import BaseTool
+from pydantic import BaseModel, Field
 
 from langchain_community.utilities.tavily_search import TavilySearchAPIWrapper
 
@@ -18,6 +19,11 @@ class TavilyInput(BaseModel):
     query: str = Field(description="search query to look up")
 
 
+@deprecated(
+    since="0.3.25",
+    removal="1.0",
+    alternative_import="langchain_tavily.TavilySearch",
+)
 class TavilySearchResults(BaseTool):
     """Tool that queries the Tavily Search API and gets back json.
 
@@ -26,42 +32,71 @@ class TavilySearchResults(BaseTool):
 
         .. code-block:: bash
 
-            pip install -U langchain-openai
+            pip install -U langchain-community tavily-python
             export TAVILY_API_KEY="your-api-key"
 
     Instantiate:
 
         .. code-block:: python
 
-            from langchain_community.tools.tavily_search import TavilySearchResults
+            from langchain_community.tools import TavilySearchResults
 
             tool = TavilySearchResults(
-                # max_results= 5
-                # search_depth = "advanced"
+                max_results=5,
+                include_answer=True,
+                include_raw_content=True,
+                include_images=True,
+                # search_depth="advanced",
                 # include_domains = []
                 # exclude_domains = []
-                # include_answer = False
-                # include_raw_content = False
-                # include_images = False
             )
 
-    Invoke:
+    Invoke directly with args:
 
         .. code-block:: python
 
-            tool = TavilySearchResults(max_results=3)
-            tool.invoke("What is the weather?")
+            tool.invoke({'query': 'who won the last french open'})
+
+        .. code-block:: json
+
+            {
+                "url": "https://www.nytimes.com...",
+                "content": "Novak Djokovic won the last French Open by beating Casper Ruud ..."
+            }
+
+    Invoke with tool call:
 
         .. code-block:: python
 
-            [{'url': 'https://www.weatherapi.com/',
-            'content': "{'location': {'name': 'Current', 'region': 'Harbour Island', 'country': 'Bahamas', 'lat': 25.43, 'lon': -76.78, 'tz_id': 'America/Nassau', 'localtime_epoch': 1718077801, 'localtime': '2024-06-10 23:50'}, 'current': {'last_updated_epoch': 1718077500, 'last_updated': '2024-06-10 23:45', 'temp_c': 27.9, 'temp_f': 82.1, 'is_day': 0, 'condition': {'text': 'Patchy rain nearby', 'icon': '//cdn.weatherapi.com/weather/64x64/night/176.png', 'code': 1063}, 'wind_mph': 14.5, 'wind_kph': 23.4, 'wind_degree': 161, 'wind_dir': 'SSE', 'pressure_mb': 1014.0, 'pressure_in': 29.94, 'precip_mm': 0.01, 'precip_in': 0.0, 'humidity': 88, 'cloud': 74, 'feelslike_c': 33.1, 'feelslike_f': 91.5, 'windchill_c': 27.9, 'windchill_f': 82.1, 'heatindex_c': 33.1, 'heatindex_f': 91.5, 'dewpoint_c': 25.6, 'dewpoint_f': 78.1, 'vis_km': 10.0, 'vis_miles': 6.0, 'uv': 1.0, 'gust_mph': 20.4, 'gust_kph': 32.9}}"},
-            {'url': 'https://www.localconditions.com/weather-ninnescah-kansas/67069/',
-            'content': 'The following chart reports what the hourly Ninnescah, KS temperature has been today, from 12:56 AM to 3:56 AM Tue, May 21st 2024. The lowest temperature reading has been 73.04 degrees fahrenheit at 3:56 AM, while the highest temperature is 75.92 degrees fahrenheit at 12:56 AM. Ninnescah KS detailed current weather report for 67069 in Kansas.'},
-            {'url': 'https://www.weather.gov/forecastmaps/',
-            'content': 'Short Range Forecasts. Short range forecast products depicting pressure patterns, circulation centers and fronts, and types and extent of precipitation. 12 Hour | 24 Hour | 36 Hour | 48 Hour.'}]
+            tool.invoke({"args": {'query': 'who won the last french open'}, "type": "tool_call", "id": "foo", "name": "tavily"})
 
-        When converting ``TavilySearchResults`` to a tool, you may want to not return all of the content resulting from ``invoke``. You can select what parts of the response to keep depending on your use case.
+        .. code-block:: python
+
+            ToolMessage(
+                content='{ "url": "https://www.nytimes.com...", "content": "Novak Djokovic won the last French Open by beating Casper Ruud ..." }',
+                artifact={
+                    'query': 'who won the last french open',
+                    'follow_up_questions': None,
+                    'answer': 'Novak ...',
+                    'images': [
+                        'https://www.amny.com/wp-content/uploads/2023/06/AP23162622181176-1200x800.jpg',
+                        ...
+                        ],
+                    'results': [
+                        {
+                            'title': 'Djokovic ...',
+                            'url': 'https://www.nytimes.com...',
+                            'content': "Novak...",
+                            'score': 0.99505633,
+                            'raw_content': 'Tennis\nNovak ...'
+                        },
+                        ...
+                    ],
+                    'response_time': 2.92
+                },
+                tool_call_id='1',
+                name='tavily_search_results_json',
+            )
 
     """  # noqa: E501
 
@@ -71,31 +106,73 @@ class TavilySearchResults(BaseTool):
         "Useful for when you need to answer questions about current events. "
         "Input should be a search query."
     )
-    api_wrapper: TavilySearchAPIWrapper = Field(default_factory=TavilySearchAPIWrapper)  # type: ignore[arg-type]
+    args_schema: Type[BaseModel] = TavilyInput
+    """The tool response format."""
+
     max_results: int = 5
     """Max search results to return, default is 5"""
     search_depth: str = "advanced"
-    '''The depth of the search. It can be "basic" or "advanced"'''
+    """The depth of the search. It can be "basic" or "advanced"
+    
+    .. versionadded:: 0.2.5
+    """
     include_domains: List[str] = []
-    """A list of domains to specifically include in the search results. Default is None, which includes all domains."""  # noqa: E501
+    """A list of domains to specifically include in the search results. 
+    
+    Default is None, which includes all domains.
+    
+    .. versionadded:: 0.2.5
+    """
     exclude_domains: List[str] = []
-    """A list of domains to specifically exclude from the search results. Default is None, which doesn't exclude any domains."""  # noqa: E501
+    """A list of domains to specifically exclude from the search results. 
+    
+    Default is None, which doesn't exclude any domains.
+    
+    .. versionadded:: 0.2.5
+    """
     include_answer: bool = False
-    """Include a short answer to original query in the search results. Default is False."""  # noqa: E501
+    """Include a short answer to original query in the search results. 
+    
+    Default is False.
+    
+    .. versionadded:: 0.2.5
+    """
     include_raw_content: bool = False
-    """Include cleaned and parsed HTML of each site search results. Default is False."""
+    """Include cleaned and parsed HTML of each site search results. 
+    
+    Default is False.
+    
+    .. versionadded:: 0.2.5
+    """
     include_images: bool = False
-    """Include a list of query related images in the response. Default is False."""
-    args_schema: Type[BaseModel] = TavilyInput
+    """Include a list of query related images in the response. 
+    
+    Default is False.
+    
+    .. versionadded:: 0.2.5
+    """
+
+    api_wrapper: TavilySearchAPIWrapper = Field(default_factory=TavilySearchAPIWrapper)  # type: ignore[arg-type]
+    response_format: Literal["content_and_artifact"] = "content_and_artifact"
+
+    def __init__(self, **kwargs: Any) -> None:
+        # Create api_wrapper with tavily_api_key if provided
+        if "tavily_api_key" in kwargs:
+            kwargs["api_wrapper"] = TavilySearchAPIWrapper(
+                tavily_api_key=kwargs["tavily_api_key"]
+            )
+
+        super().__init__(**kwargs)
 
     def _run(
         self,
         query: str,
         run_manager: Optional[CallbackManagerForToolRun] = None,
-    ) -> Union[List[Dict], str]:
+    ) -> Tuple[Union[List[Dict[str, str]], str], Dict]:
         """Use the tool."""
+        # TODO: remove try/except, should be handled by BaseTool
         try:
-            return self.api_wrapper.results(
+            raw_results = self.api_wrapper.raw_results(
                 query,
                 self.max_results,
                 self.search_depth,
@@ -106,16 +183,17 @@ class TavilySearchResults(BaseTool):
                 self.include_images,
             )
         except Exception as e:
-            return repr(e)
+            return repr(e), {}
+        return self.api_wrapper.clean_results(raw_results["results"]), raw_results
 
     async def _arun(
         self,
         query: str,
         run_manager: Optional[AsyncCallbackManagerForToolRun] = None,
-    ) -> Union[List[Dict], str]:
+    ) -> Tuple[Union[List[Dict[str, str]], str], Dict]:
         """Use the tool asynchronously."""
         try:
-            return await self.api_wrapper.results_async(
+            raw_results = await self.api_wrapper.raw_results_async(
                 query,
                 self.max_results,
                 self.search_depth,
@@ -126,9 +204,15 @@ class TavilySearchResults(BaseTool):
                 self.include_images,
             )
         except Exception as e:
-            return repr(e)
+            return repr(e), {}
+        return self.api_wrapper.clean_results(raw_results["results"]), raw_results
 
 
+@deprecated(
+    since="0.3.25",
+    removal="1.0",
+    alternative_import="langchain_tavily.TavilySearch",
+)
 class TavilyAnswer(BaseTool):
     """Tool that queries the Tavily Search API and gets back an answer."""
 
