@@ -2,8 +2,8 @@
 
 from typing import Any, Dict, Optional
 
-from langchain_core.pydantic_v1 import BaseModel, Extra, root_validator
 from langchain_core.utils import get_from_dict_or_env
+from pydantic import BaseModel, ConfigDict, model_validator
 
 
 class DataheraldAPIWrapper(BaseModel):
@@ -18,17 +18,17 @@ class DataheraldAPIWrapper(BaseModel):
 
     """
 
-    dataherald_client: Any  #: :meta private:
+    dataherald_client: Any = None  #: :meta private:
     db_connection_id: str
     dataherald_api_key: Optional[str] = None
 
-    class Config:
-        """Configuration for this pydantic object."""
+    model_config = ConfigDict(
+        extra="forbid",
+    )
 
-        extra = Extra.forbid
-
-    @root_validator(pre=True)
-    def validate_environment(cls, values: Dict) -> Dict:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_environment(cls, values: Dict) -> Any:
         """Validate that api key and python package exists in environment."""
         dataherald_api_key = get_from_dict_or_env(
             values, "dataherald_api_key", "DATAHERALD_API_KEY"
