@@ -4,9 +4,9 @@ No setup required. Free.
 https://pypi.org/project/duckduckgo-search/
 """
 
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
-from langchain_core.pydantic_v1 import BaseModel, Extra, root_validator
+from pydantic import BaseModel, ConfigDict, model_validator
 
 
 class DuckDuckGoSearchAPIWrapper(BaseModel):
@@ -28,29 +28,29 @@ class DuckDuckGoSearchAPIWrapper(BaseModel):
     Options: d, w, m, y
     """
     max_results: int = 5
-    backend: str = "api"
+    backend: str = "auto"
     """
-    Options: api, html, lite
+    Options: auto, html, lite
     """
     source: str = "text"
     """
-    Options: text, news
+    Options: text, news, images
     """
 
-    class Config:
-        """Configuration for this pydantic object."""
+    model_config = ConfigDict(
+        extra="forbid",
+    )
 
-        extra = Extra.forbid
-
-    @root_validator(pre=True)
-    def validate_environment(cls, values: Dict) -> Dict:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_environment(cls, values: Dict) -> Any:
         """Validate that python package exists in environment."""
         try:
-            from duckduckgo_search import DDGS  # noqa: F401
+            from ddgs import DDGS  # noqa: F401
         except ImportError:
             raise ImportError(
-                "Could not import duckduckgo-search python package. "
-                "Please install it with `pip install -U duckduckgo-search`."
+                "Could not import ddgs python package. "
+                "Please install it with `pip install -U ddgs`."
             )
         return values
 
@@ -58,7 +58,7 @@ class DuckDuckGoSearchAPIWrapper(BaseModel):
         self, query: str, max_results: Optional[int] = None
     ) -> List[Dict[str, str]]:
         """Run query through DuckDuckGo text search and return results."""
-        from duckduckgo_search import DDGS
+        from ddgs import DDGS
 
         with DDGS() as ddgs:
             ddgs_gen = ddgs.text(
@@ -77,7 +77,7 @@ class DuckDuckGoSearchAPIWrapper(BaseModel):
         self, query: str, max_results: Optional[int] = None
     ) -> List[Dict[str, str]]:
         """Run query through DuckDuckGo news search and return results."""
-        from duckduckgo_search import DDGS
+        from ddgs import DDGS
 
         with DDGS() as ddgs:
             ddgs_gen = ddgs.news(
@@ -91,12 +91,31 @@ class DuckDuckGoSearchAPIWrapper(BaseModel):
                 return [r for r in ddgs_gen]
         return []
 
+    def _ddgs_images(
+        self, query: str, max_results: Optional[int] = None
+    ) -> List[Dict[str, str]]:
+        """Run query through DuckDuckGo image search and return results."""
+        from ddgs import DDGS
+
+        with DDGS() as ddgs:
+            ddgs_gen = ddgs.images(
+                query,
+                region=self.region,
+                safesearch=self.safesearch,
+                max_results=max_results or self.max_results,
+            )
+            if ddgs_gen:
+                return [r for r in ddgs_gen]
+        return []
+
     def run(self, query: str) -> str:
         """Run query through DuckDuckGo and return concatenated results."""
         if self.source == "text":
             results = self._ddgs_text(query)
         elif self.source == "news":
             results = self._ddgs_news(query)
+        elif self.source == "images":
+            results = self._ddgs_images(query)
         else:
             results = []
 
@@ -137,6 +156,19 @@ class DuckDuckGoSearchAPIWrapper(BaseModel):
                 }
                 for r in self._ddgs_news(query, max_results=max_results)
             ]
+        elif source == "images":
+            results = [
+                {
+                    "title": r["title"],
+                    "thumbnail": r["thumbnail"],
+                    "image": r["image"],
+                    "url": r["url"],
+                    "height": r["height"],
+                    "width": r["width"],
+                    "source": r["source"],
+                }
+                for r in self._ddgs_images(query, max_results=max_results)
+            ]
         else:
             results = []
 
