@@ -5,12 +5,12 @@ https://docs.tavily.com/docs/tavily-api/introduction
 """
 
 import json
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 import aiohttp
 import requests
-from langchain_core.pydantic_v1 import BaseModel, Extra, SecretStr, root_validator
 from langchain_core.utils import get_from_dict_or_env
+from pydantic import BaseModel, ConfigDict, SecretStr, model_validator
 
 TAVILY_API_URL = "https://api.tavily.com"
 
@@ -20,13 +20,13 @@ class TavilySearchAPIWrapper(BaseModel):
 
     tavily_api_key: SecretStr
 
-    class Config:
-        """Configuration for this pydantic object."""
+    model_config = ConfigDict(
+        extra="forbid",
+    )
 
-        extra = Extra.forbid
-
-    @root_validator(pre=True)
-    def validate_environment(cls, values: Dict) -> Dict:
+    @model_validator(mode="before")
+    @classmethod
+    def validate_environment(cls, values: Dict) -> Any:
         """Validate that api key and endpoint exists in environment."""
         tavily_api_key = get_from_dict_or_env(
             values, "tavily_api_key", "TAVILY_API_KEY"
@@ -58,7 +58,6 @@ class TavilySearchAPIWrapper(BaseModel):
             "include_images": include_images,
         }
         response = requests.post(
-            # type: ignore
             f"{TAVILY_API_URL}/search",
             json=params,
         )
@@ -176,10 +175,13 @@ class TavilySearchAPIWrapper(BaseModel):
         """Clean results from Tavily Search API."""
         clean_results = []
         for result in results:
-            clean_results.append(
-                {
-                    "url": result["url"],
-                    "content": result["content"],
-                }
-            )
+            clean_result = {
+                "title": result["title"],
+                "url": result["url"],
+                "content": result["content"],
+                "score": result["score"],
+            }
+            if raw_content := result.get("raw_content"):
+                clean_result["raw_content"] = raw_content
+            clean_results.append(clean_result)
         return clean_results
