@@ -8,8 +8,8 @@ from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 from langchain_core.documents import Document
 from langchain_core.embeddings import Embeddings
-from langchain_core.pydantic_v1 import BaseSettings
 from langchain_core.vectorstores import VectorStore
+from pydantic_settings import BaseSettings, SettingsConfigDict
 
 logger = logging.getLogger()
 
@@ -95,25 +95,133 @@ class ClickhouseSettings(BaseSettings):
     def __getitem__(self, item: str) -> Any:
         return getattr(self, item)
 
-    class Config:
-        env_file = ".env"
-        env_prefix = "clickhouse_"
-        env_file_encoding = "utf-8"
+    model_config = SettingsConfigDict(
+        env_file=".env",
+        env_file_encoding="utf-8",
+        env_prefix="clickhouse_",
+        extra="ignore",
+    )
 
 
 class Clickhouse(VectorStore):
-    """`ClickHouse VectorSearch` vector store.
+    """ClickHouse vector store integration.
 
-    You need a `clickhouse-connect` python package, and a valid account
-    to connect to ClickHouse.
+    Setup:
+        Install ``langchain_community`` and ``clickhouse-connect``:
 
-    ClickHouse can not only search with simple vector indexes,
-    it also supports complex query with multiple conditions,
-    constraints and even sub-queries.
+        .. code-block:: bash
 
-    For more information, please visit
-        [ClickHouse official site](https://clickhouse.com/clickhouse)
-    """
+            pip install -qU langchain_community clickhouse-connect
+
+    Key init args — indexing params:
+        embedding: Embeddings
+            Embedding function to use.
+
+    Key init args — client params:
+        config: Optional[ClickhouseSettings]
+            ClickHouse client configuration.
+
+    Instantiate:
+        .. code-block:: python
+
+            from langchain_community.vectorstores import Clickhouse, ClickhouseSettings
+            from langchain_openai import OpenAIEmbeddings
+
+            settings = ClickhouseSettings(table="clickhouse_example")
+            vector_store = Clickhouse(embedding=OpenAIEmbeddings(), config=settings)
+
+    Add Documents:
+        .. code-block:: python
+
+            from langchain_core.documents import Document
+
+            document_1 = Document(page_content="foo", metadata={"baz": "bar"})
+            document_2 = Document(page_content="thud", metadata={"bar": "baz"})
+            document_3 = Document(page_content="i will be deleted :(")
+
+            documents = [document_1, document_2, document_3]
+            ids = ["1", "2", "3"]
+            vector_store.add_documents(documents=documents, ids=ids)
+
+    Delete Documents:
+        .. code-block:: python
+
+            vector_store.delete(ids=["3"])
+
+    # TODO: Fill out example output.
+    Search:
+        .. code-block:: python
+
+            results = vector_store.similarity_search(query="thud",k=1)
+            for doc in results:
+                print(f"* {doc.page_content} [{doc.metadata}]")
+
+        .. code-block:: python
+
+            # TODO: Example output
+
+    # TODO: Fill out with relevant variables and example output.
+    Search with filter:
+        .. code-block:: python
+
+            # TODO: Edit filter if needed
+            results = vector_store.similarity_search(query="thud",k=1,filter="metadata.baz='bar'")
+            for doc in results:
+                print(f"* {doc.page_content} [{doc.metadata}]")
+
+        .. code-block:: python
+
+            # TODO: Example output
+
+    # TODO: Fill out with example output.
+    Search with score:
+        .. code-block:: python
+
+            results = vector_store.similarity_search_with_score(query="qux",k=1)
+            for doc, score in results:
+                print(f"* [SIM={score:3f}] {doc.page_content} [{doc.metadata}]")
+
+        .. code-block:: python
+
+            # TODO: Example output
+
+    # TODO: Fill out with example output.
+    Async:
+        .. code-block:: python
+
+            # add documents
+            # await vector_store.aadd_documents(documents=documents, ids=ids)
+
+            # delete documents
+            # await vector_store.adelete(ids=["3"])
+
+            # search
+            # results = vector_store.asimilarity_search(query="thud",k=1)
+
+            # search with score
+            results = await vector_store.asimilarity_search_with_score(query="qux",k=1)
+            for doc,score in results:
+                print(f"* [SIM={score:3f}] {doc.page_content} [{doc.metadata}]")
+
+        .. code-block:: python
+
+            # TODO: Example output
+
+    # TODO: Fill out with example output.
+    Use as Retriever:
+        .. code-block:: python
+
+            retriever = vector_store.as_retriever(
+                search_type="mmr",
+                search_kwargs={"k": 1, "fetch_k": 2, "lambda_mult": 0.5},
+            )
+            retriever.invoke("thud")
+
+        .. code-block:: python
+
+            # TODO: Example output
+
+    """  # noqa: E501
 
     def __init__(
         self,
@@ -123,10 +231,11 @@ class Clickhouse(VectorStore):
     ) -> None:
         """ClickHouse Wrapper to LangChain
 
-        embedding_function (Embeddings):
-        config (ClickHouseSettings): Configuration to ClickHouse Client
-        Other keyword arguments will pass into
-            [clickhouse-connect](https://docs.clickhouse.com/)
+        Args:
+            embedding_function (Embeddings): embedding function to use
+            config (ClickHouseSettings): Configuration to ClickHouse Client
+            kwargs (any): Other keyword arguments will pass into
+                [clickhouse-connect](https://docs.clickhouse.com/)
         """
         try:
             from clickhouse_connect import get_client
@@ -200,6 +309,14 @@ class Clickhouse(VectorStore):
             **kwargs,
         )
         # Enable JSON type
+        try:
+            self.client.command("SET allow_experimental_json_type=1")
+        except Exception as _:
+            logger.debug(
+                f"Clickhouse version={self.client.server_version} - "
+                "There is no allow_experimental_json_type parameter."
+            )
+
         self.client.command("SET allow_experimental_object_type=1")
         if self.config.index_type:
             # Enable index
@@ -224,27 +341,28 @@ class Clickhouse(VectorStore):
         if self.config.index_type:
             return f"""\
         CREATE TABLE IF NOT EXISTS {self.config.database}.{self.config.table}(
-            {self.config.column_map['id']} Nullable(String),
-            {self.config.column_map['document']} Nullable(String),
-            {self.config.column_map['embedding']} Array(Float32),
-            {self.config.column_map['metadata']} JSON,
-            {self.config.column_map['uuid']} UUID DEFAULT generateUUIDv4(),
+            {self.config.column_map["id"]} Nullable(String),
+            {self.config.column_map["document"]} Nullable(String),
+            {self.config.column_map["embedding"]} Array(Float32),
+            {self.config.column_map["metadata"]} JSON,
+            {self.config.column_map["uuid"]} UUID DEFAULT generateUUIDv4(),
             CONSTRAINT cons_vec_len CHECK length(
-                {self.config.column_map['embedding']}) = {dim},
-            INDEX vec_idx {self.config.column_map['embedding']} TYPE \
+                {self.config.column_map["embedding"]}) = {dim},
+            INDEX vec_idx {self.config.column_map["embedding"]} TYPE \
         {self.config.index_type}({index_params}) GRANULARITY 1000
         ) ENGINE = MergeTree ORDER BY uuid SETTINGS index_granularity = 8192\
         """
         else:
             return f"""\
                 CREATE TABLE IF NOT EXISTS {self.config.database}.{self.config.table}(
-                    {self.config.column_map['id']} Nullable(String),
-                    {self.config.column_map['document']} Nullable(String),
-                    {self.config.column_map['embedding']} Array(Float32),
-                    {self.config.column_map['metadata']} JSON,
-                    {self.config.column_map['uuid']} UUID DEFAULT generateUUIDv4(),
+                    {self.config.column_map["id"]} Nullable(String),
+                    {self.config.column_map["document"]} Nullable(String),
+                    {self.config.column_map["embedding"]} Array(Float32),
+                    {self.config.column_map["metadata"]} JSON,
+                    {self.config.column_map["uuid"]} UUID DEFAULT generateUUIDv4(),
                     CONSTRAINT cons_vec_len CHECK length({
-                        self.config.column_map['embedding']}) = {dim}
+                self.config.column_map["embedding"]
+            }) = {dim}
                 ) ENGINE = MergeTree ORDER BY uuid
                 """
 
@@ -301,7 +419,7 @@ class Clickhouse(VectorStore):
                 INSERT INTO TABLE 
                     {self.config.database}.{self.config.table}({ks})
                 VALUES
-                {','.join(_data)}
+                {",".join(_data)}
                 """
         return i_str
 
@@ -457,13 +575,13 @@ class Clickhouse(VectorStore):
             for k in self.config.index_query_params:
                 settings_strs.append(f"SETTING {k}={self.config.index_query_params[k]}")
         q_str = f"""
-            SELECT {self.config.column_map['document']}, 
-                {self.config.column_map['metadata']}, dist
+            SELECT {self.config.column_map["document"]}, 
+                {self.config.column_map["metadata"]}, dist
             FROM {self.config.database}.{self.config.table}
             {where_str}
-            ORDER BY L2Distance({self.config.column_map['embedding']}, [{q_emb_str}]) 
+            ORDER BY L2Distance({self.config.column_map["embedding"]}, [{q_emb_str}]) 
                 AS dist {self.dist_order}
-            LIMIT {topk} {' '.join(settings_strs)}
+            LIMIT {topk} {" ".join(settings_strs)}
             """
         return q_str
 
