@@ -14,8 +14,8 @@ if TYPE_CHECKING:
 
 @deprecated(
     since="0.2.4",
-    removal="0.3.0",
-    alternative_import="langchain_couchbase.CouchbaseVectorStore",
+    removal="1.0",
+    alternative_import="langchain_couchbase.CouchbaseSearchVectorStore",
 )
 class CouchbaseVectorStore(VectorStore):
     """`Couchbase Vector Store` vector store.
@@ -60,10 +60,10 @@ class CouchbaseVectorStore(VectorStore):
     """
 
     # Default batch size
-    DEFAULT_BATCH_SIZE = 100
-    _metadata_key = "metadata"
-    _default_text_key = "text"
-    _default_embedding_key = "embedding"
+    DEFAULT_BATCH_SIZE: int = 100
+    _metadata_key: str = "metadata"
+    _default_text_key: str = "text"
+    _default_embedding_key: str = "embedding"
 
     def _check_bucket_exists(self) -> bool:
         """Check if the bucket exists in the linked Couchbase cluster"""
@@ -546,6 +546,15 @@ class CouchbaseVectorStore(VectorStore):
         embedding_key = kwargs.get("embedding_key", cls._default_embedding_key)
         scoped_index = kwargs.get("scoped_index", True)
 
+        if bucket_name is None:
+            raise ValueError("bucket_name must be provided")
+        if scope_name is None:
+            raise ValueError("scope_name must be provided")
+        if collection_name is None:
+            raise ValueError("collection_name must be provided")
+        if index_name is None:
+            raise ValueError("index_name must be provided")
+
         return cls(
             embedding=embedding,
             cluster=cluster,
