@@ -43,7 +43,8 @@ class LanceDB(VectorStore):
         table_name: Name of the table to use. Defaults to ``vectorstore``.
         api_key: API key to use for LanceDB cloud database.
         region: Region to use for LanceDB cloud database.
-        mode: Mode to use for adding data to the table. Defaults to ``overwrite``.
+        mode: Mode to use for adding data to the table. Valid values are
+              ``append`` and ``overwrite``. Defaults to ``overwrite``.
 
 
 
@@ -74,6 +75,7 @@ class LanceDB(VectorStore):
     ):
         """Initialize with Lance DB vectorstore"""
         lancedb = guard_import("lancedb")
+        lancedb.remote.table = guard_import("lancedb.remote.table")
         self._embedding = embedding
         self._vector_key = vector_key
         self._id_key = id_key
@@ -150,12 +152,14 @@ class LanceDB(VectorStore):
             score_col = "_relevance_score"
         else:
             score_col = None
+        # Check if 'metadata' is in the columns
+        has_metadata = "metadata" in columns
 
         if score_col is None or not score:
             return [
                 Document(
                     page_content=results[self._text_key][idx].as_py(),
-                    metadata=results["metadata"][idx].as_py(),
+                    metadata=results["metadata"][idx].as_py() if has_metadata else {},
                 )
                 for idx in range(len(results))
             ]
@@ -164,7 +168,9 @@ class LanceDB(VectorStore):
                 (
                     Document(
                         page_content=results[self._text_key][idx].as_py(),
-                        metadata=results["metadata"][idx].as_py(),
+                        metadata=results["metadata"][idx].as_py()
+                        if has_metadata
+                        else {},
                     ),
                     results[score_col][idx].as_py(),
                 )
@@ -195,7 +201,7 @@ class LanceDB(VectorStore):
         """
         docs = []
         ids = ids or [str(uuid.uuid4()) for _ in texts]
-        embeddings = self._embedding.embed_documents(list(texts))  # type: ignore
+        embeddings = self._embedding.embed_documents(list(texts))  # type: ignore[union-attr]
         for idx, text in enumerate(texts):
             embedding = embeddings[idx]
             metadata = metadatas[idx] if metadatas else {"id": ids[idx]}
@@ -484,7 +490,7 @@ class LanceDB(VectorStore):
                     embedding = self._embedding.embed_query(query)
                     _query = (embedding, query)
                 else:
-                    _query = query  # type: ignore
+                    _query = query  # type: ignore[assignment]
 
                 res = self._query(_query, k, filter=filter, name=name, **kwargs)
                 return self.results_to_docs(res, score=score)
@@ -557,7 +563,7 @@ class LanceDB(VectorStore):
 
         if self._embedding is None:
             raise ValueError(
-                "For MMR search, you must specify an embedding function on" "creation."
+                "For MMR search, you must specify an embedding function oncreation."
             )
 
         embedding = self._embedding.embed_query(query)
@@ -675,7 +681,7 @@ class LanceDB(VectorStore):
         if filter:
             tbl.delete(filter)
         elif ids:
-            tbl.delete("id in ('{}')".format(",".join(ids)))
+            tbl.delete(f"{self._id_key} in ('{{}}')".format(",".join(ids)))
         elif drop_columns:
             if self.api_key is not None:
                 raise NotImplementedError(
