@@ -109,9 +109,12 @@ class Marqo(VectorStore):
             List[str]: The list of ids that were added.
         """
 
-        if self._client.index(self._index_name).get_settings()["index_defaults"][
-            "treat_urls_and_pointers_as_images"
-        ]:
+        settings = self._client.index(self._index_name).get_settings()
+        if (
+            "index_defaults" in settings
+            and settings["index_defaults"]["treat_urls_and_pointers_as_images"]
+            or settings.get("treat_urls_and_pointers_as_images")
+        ):
             raise ValueError(
                 "Marqo.add_texts is disabled for multimodal indexes. To add documents "
                 "with a multimodal index use the Python client for Marqo directly."
@@ -266,7 +269,10 @@ class Marqo(VectorStore):
 
             metadata = json.loads(res.get("metadata", "{}"))
             documents.append(
-                (Document(page_content=text, metadata=metadata), res["_score"])
+                (
+                    Document(page_content=text, metadata=metadata),
+                    res["_score"],
+                )
             )
         return documents
 
