@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import logging
-from typing import Any, Iterable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Iterable, List, Optional, Tuple, Union
 from uuid import uuid4
 
 import numpy as np
@@ -12,6 +12,9 @@ from langchain_core.vectorstores import VectorStore
 
 from langchain_community.vectorstores.utils import maximal_marginal_relevance
 
+if TYPE_CHECKING:
+    from pymilvus.orm.mutation import MutationResult
+
 logger = logging.getLogger(__name__)
 
 DEFAULT_MILVUS_CONNECTION = {
@@ -25,7 +28,7 @@ DEFAULT_MILVUS_CONNECTION = {
 
 @deprecated(
     since="0.2.0",
-    removal="0.3.0",
+    removal="1.0",
     alternative_import="langchain_milvus.MilvusVectorStore",
 )
 class Milvus(VectorStore):
@@ -235,10 +238,10 @@ class Milvus(VectorStore):
         from pymilvus import MilvusException, connections
 
         # Grab the connection arguments that are used for checking existing connection
-        host: str = connection_args.get("host", None)
-        port: Union[str, int] = connection_args.get("port", None)
-        address: str = connection_args.get("address", None)
-        uri: str = connection_args.get("uri", None)
+        host: Optional[str] = connection_args.get("host", None)
+        port: Optional[Union[str, int]] = connection_args.get("port", None)
+        address: Optional[str] = connection_args.get("address", None)
+        uri: Optional[str] = connection_args.get("uri", None)
         user = connection_args.get("user", None)
 
         # Order of use is host/port, uri, address
@@ -550,15 +553,15 @@ class Milvus(VectorStore):
 
         texts = list(texts)
         if not self.auto_id:
-            assert isinstance(
-                ids, list
-            ), "A list of valid ids are required when auto_id is False."
-            assert len(set(ids)) == len(
-                texts
-            ), "Different lengths of texts and unique ids are provided."
-            assert all(
-                len(x.encode()) <= 65_535 for x in ids
-            ), "Each id should be a string less than 65535 bytes."
+            assert isinstance(ids, list), (
+                "A list of valid ids are required when auto_id is False."
+            )
+            assert len(set(ids)) == len(texts), (
+                "Different lengths of texts and unique ids are provided."
+            )
+            assert all(len(x.encode()) <= 65_535 for x in ids), (
+                "Each id should be a string less than 65535 bytes."
+            )
 
         try:
             embeddings = self.embedding_func.embed_documents(texts)
@@ -938,9 +941,9 @@ class Milvus(VectorStore):
                 ret.append(documents[x])
         return ret
 
-    def delete(  # type: ignore[no-untyped-def]
-        self, ids: Optional[List[str]] = None, expr: Optional[str] = None, **kwargs: str
-    ):
+    def delete(
+        self, ids: Optional[List[str]] = None, expr: Optional[str] = None, **kwargs: Any
+    ) -> MutationResult:
         """Delete by vector ID or boolean expression.
         Refer to [Milvus documentation](https://milvus.io/docs/delete_data.md)
         for notes and examples of expressions.
@@ -953,13 +956,13 @@ class Milvus(VectorStore):
         if isinstance(ids, list) and len(ids) > 0:
             if expr is not None:
                 logger.warning(
-                    "Both ids and expr are provided. " "Ignore expr and delete by ids."
+                    "Both ids and expr are provided. Ignore expr and delete by ids."
                 )
             expr = f"{self._primary_field} in {ids}"
         else:
-            assert isinstance(
-                expr, str
-            ), "Either ids list or expr string must be provided."
+            assert isinstance(expr, str), (
+                "Either ids list or expr string must be provided."
+            )
         return self.col.delete(expr=expr, **kwargs)  # type: ignore[union-attr]
 
     @classmethod
@@ -1053,7 +1056,7 @@ class Milvus(VectorStore):
         pks = [item.get(self._primary_field) for item in query_result]
         return pks
 
-    def upsert(  # type: ignore[override]
+    def upsert(
         self,
         ids: Optional[List[str]] = None,
         documents: List[Document] | None = None,
