@@ -23,10 +23,11 @@ class Vald(VectorStore):
             from langchain_community.embeddings import HuggingFaceEmbeddings
             from langchain_community.vectorstores import Vald
 
+            model_name = "sentence-transformers/all-mpnet-base-v2"
             texts = ['foo', 'bar', 'baz']
             vald = Vald.from_texts(
                 texts=texts,
-                embedding=HuggingFaceEmbeddings(),
+                embedding=HuggingFaceEmbeddings(model_name=model_name),
                 host="localhost",
                 port=8080,
                 skip_strict_exist_check=False,
