@@ -16,11 +16,13 @@ from langchain_core.documents import Document
 from langchain_core.embeddings import Embeddings
 from langchain_core.runnables import Runnable, RunnableConfig
 from langchain_core.vectorstores import VectorStore, VectorStoreRetriever
+from pydantic import ConfigDict
 
 logger = logging.getLogger(__name__)
 
 MMR_RERANKER_ID = 272725718
 RERANKER_MULTILINGUAL_V1_ID = 272725719
+UDF_RERANKER_ID = 272725722
 
 
 @dataclass
@@ -37,7 +39,7 @@ class SummaryConfig:
     is_enabled: bool = False
     max_results: int = 7
     response_lang: str = "eng"
-    prompt_name: str = "vectara-summary-ext-v1.2.0"
+    prompt_name: str = "vectara-summary-ext-24-05-med-omni"
     stream: bool = False
 
 
@@ -66,7 +68,7 @@ class MMRConfig:
 class RerankConfig:
     """Configuration for Reranker.
 
-    reranker: "mmr", "rerank_multilingual_v1" or "none"
+    reranker: "mmr", "rerank_multilingual_v1", "udf" or "none"
     rerank_k: number of results to fetch before reranking, defaults to 50
     mmr_diversity_bias: for MMR only - a number between 0 and 1 that determines
         the degree of diversity among the results with 0 corresponding
@@ -75,11 +77,13 @@ class RerankConfig:
         Note: mmr_diversity_bias is equivalent 1-lambda_mult
         where lambda_mult is the value often used in max_marginal_relevance_search()
         We chose to use that since we believe it's more intuitive to the user.
+    user_function: for UDF only - the user function to use for reranking.
     """
 
     reranker: str = "none"
     rerank_k: int = 50
     mmr_diversity_bias: float = 0.3
+    user_function: str = ""
 
 
 @dataclass
@@ -444,7 +448,7 @@ class Vectara(VectorStore):
                         config.rerank_config.rerank_k
                         if (
                             config.rerank_config.reranker
-                            in ["mmr", "rerank_multilingual_v1"]
+                            in ["mmr", "udf", "rerank_multilingual_v1"]
                         )
                         else config.k
                     ),
@@ -463,7 +467,7 @@ class Vectara(VectorStore):
         }
 
         if config.lambda_val > 0:
-            body["query"][0]["corpusKey"][0]["lexicalInterpolationConfig"] = {  # type: ignore
+            body["query"][0]["corpusKey"][0]["lexicalInterpolationConfig"] = {  # type: ignore[index]
                 "lambda": config.lambda_val
             }
 
@@ -472,6 +476,11 @@ class Vectara(VectorStore):
                 "rerankerId": MMR_RERANKER_ID,
                 "mmrConfig": {"diversityBias": config.rerank_config.mmr_diversity_bias},
             }
+        elif config.rerank_config.reranker == "udf":
+            body["query"][0]["rerankingConfig"] = {
+                "rerankerId": UDF_RERANKER_ID,
+                "userFunction": config.rerank_config.user_function,
+            }
         elif config.rerank_config.reranker == "rerank_multilingual_v1":
             body["query"][0]["rerankingConfig"] = {
                 "rerankerId": RERANKER_MULTILINGUAL_V1_ID,
@@ -486,7 +495,7 @@ class Vectara(VectorStore):
                 }
             ]
             if chat:
-                body["query"][0]["summary"][0]["chat"] = {  # type: ignore
+                body["query"][0]["summary"][0]["chat"] = {  # type: ignore[index]
                     "store": True,
                     "conversationId": chat_conv_id,
                 }
@@ -731,15 +740,14 @@ class VectaraRetriever(VectorStoreRetriever):
     config: VectaraQueryConfig
     """Configuration for this retriever."""
 
-    class Config:
-        """Configuration for this pydantic object."""
-
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(
+        arbitrary_types_allowed=True,
+    )
 
     def _get_relevant_documents(
-        self, query: str, *, run_manager: CallbackManagerForRetrieverRun
+        self, query: str, *, run_manager: CallbackManagerForRetrieverRun, **kwargs: Any
     ) -> List[Document]:
-        docs_and_scores = self.vectorstore.vectara_query(query, self.config)
+        docs_and_scores = self.vectorstore.vectara_query(query, self.config, **kwargs)
         return [doc for doc, _ in docs_and_scores]
 
     def add_documents(self, documents: List[Document], **kwargs: Any) -> List[str]:
@@ -888,6 +896,7 @@ class VectaraRAG(Runnable):
         self,
         input: str,
         config: Optional[RunnableConfig] = None,
+        **kwargs: Any,
     ) -> dict:
         res = {"answer": ""}
         for chunk in self.stream(input):
